@@ -53,37 +53,36 @@ Dark = "dark"
 DWMWA_USE_IMMERSIVE_DARK_MODE = 20
 
 
-def UpGrade(Library, Basic=True, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
+def UpGrade(Library, Basic: bool = True, Preview: bool = False, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
     import os
     import sys
     if Basic:
-        print(f"{sys.executable} -m pip install {Library}  -i {Pypi} --upgrade")
-        os.system(f"{sys.executable} -m pip install {Library}  -i {Pypi} --upgrade")
-    else:
-        print(f"{sys.executable} -m pip install {Library} --upgrade")
-        os.system(f"{sys.executable} -m pip install {Library} --upgrade")
+        Librarys = f"-i {Pypi}"
+    if Preview:
+        Pre = f"--pre"
+    print(f"{sys.executable} -m pip install {Library} {Librarys} {Pre} --upgrade")
+    os.system(f"{sys.executable} -m pip install {Library} {Librarys} {Pre} --upgrade")
 
-
-def Install(Library, Basic=True, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
+def Install(Library, Basic: bool = True, Preview: bool = False, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
     import os
     import sys
     if Basic:
-        print(f"{sys.executable} -m pip install {Library}  -i {Pypi}")
-        os.system(f"{sys.executable} -m pip install {Library}  -i {Pypi}")
-    else:
-        print(f"{sys.executable} -m pip install {Library}")
-        os.system(f"{sys.executable} -m pip install {Library}")
+        Librarys = f"-i {Pypi}"
+    if Preview:
+        Pre = f"--pre"
+    print(f"{sys.executable} -m pip install {Library} {Librarys} {Pre}")
+    os.system(f"{sys.executable} -m pip install {Library} {Librarys} {Pre}")
 
 
-def Install_ALL(Basic=True, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
-    Install("tkinter-tooltip", Basic=Basic, Pypi=Pypi)
-    Install("pywin32", Basic=Basic, Pypi=Pypi)
+def Install_ALL(Basic=True, Preview: bool = False, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
+    Install("tkinter-tooltip", Basic=Basic, Pypi=Pypi, Preview=Preview)
+    Install("pywin32", Basic=Basic, Pypi=Pypi, Preview=Preview)
     if sys.platform == "win32" and sys.getwindowsversion().build >= 22000:
-        Install("win32mica", Basic=Basic, Pypi=Pypi)
-    Install("BlurWindow", Basic=Basic, Pypi=Pypi)
-    Install("darkdetect", Basic=Basic, Pypi=Pypi)
-    Install("tkcap", Basic=Basic, Pypi=Pypi)
-    Install("Deprecated", Basic=Basic, Pypi=Pypi)
+        Install("win32mica", Basic=Basic, Pypi=Pypi, Preview=Preview)
+    Install("BlurWindow", Basic=Basic, Pypi=Pypi, Preview=Preview)
+    Install("darkdetect", Basic=Basic, Pypi=Pypi, Preview=Preview)
+    Install("tkcap", Basic=Basic, Pypi=Pypi, Preview=Preview)
+    Install("Deprecated", Basic=Basic, Pypi=Pypi, Preview=Preview)
 
 
 def UnInstall(Library):
@@ -358,6 +357,7 @@ def window_border(window: tk.Tk):
         UpdateWindow(hWnd)
     window.after(100, border)
 
+
 def window_embed(window: tk.Tk, toplevel: tk.Toplevel, iswindow: bool = True):
     def embed():
         SetParent(GetParent(toplevel.winfo_id()), window.winfo_id())
